@@ -1,13 +1,13 @@
 # PyAlgoTrade
-# 
-# Copyright 2012 Gabriel Martin Becedillas Ruiz
-# 
+#
+# Copyright 2011-2014 Gabriel Martin Becedillas Ruiz
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #   http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,16 +16,17 @@
 
 import logging
 
+
 class Logger:
-	def __init__(self, maxErrors = 20):
-		self.__maxErrors = maxErrors 
+    def __init__(self, maxErrors=None):
+        self.__maxErrors = maxErrors
 
-	def info(self, msg):
-		logging.info(msg)
+    def info(self, msg):
+        logging.info(msg)
 
-	def error(self, msg):
-		if self.__maxErrors > 0:
-			self.__maxErrors -= 1
-			logging.error(msg)
+    def error(self, msg):
+        if self.__maxErrors is not None and self.__maxErrors > 0:
+            self.__maxErrors -= 1
+            logging.error(msg)
 
-logging.getLogger().setLevel(logging.DEBUG)
+# logging.getLogger().setLevel(logging.DEBUG)
