@@ -1,25 +1,23 @@
 # PyAlgoTrade
-# 
-# Copyright 2012 Gabriel Martin Becedillas Ruiz
-# 
+#
+# Copyright 2011-2014 Gabriel Martin Becedillas Ruiz
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #   http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import rsi2
-import triple_ma_crossover
 
-# Export strategies here.
+# Export strategy classes here. The full class path must be used.
 def get_strategy_classes():
-	ret = []
-	ret.append(rsi2.Strategy)
-	ret.append(triple_ma_crossover.Strategy)
-	return ret
+    ret = []
+    ret.append("strategies.rsi2.Strategy")
+    ret.append("strategies.triple_ma_crossover.Strategy")
+    return ret
