@@ -1,13 +1,13 @@
 # PyAlgoTrade
-# 
-# Copyright 2012 Gabriel Martin Becedillas Ruiz
-# 
+#
+# Copyright 2011-2014 Gabriel Martin Becedillas Ruiz
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #   http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -18,20 +18,20 @@
 .. moduleauthor:: Gabriel Martin Becedillas Ruiz <gabriel.becedillas@gmail.com>
 """
 
-class Database:
-	def addBars(self, bars, frequency):
-		for instrument in bars.getInstruments():
-			bar = bars.getBar(instrument)
-			self.addBar(instrument, bar, frequency)
 
-	def addBarsFromFeed(self, feed):
-		for dateTime, bars in feed:
-			if bars:
-				self.addBars(bars, feed.getFrequency())
+class Database(object):
+    def addBars(self, bars, frequency):
+        for instrument in bars.getInstruments():
+            bar = bars.getBar(instrument)
+            self.addBar(instrument, bar, frequency)
 
-	def addBar(self, instrument, bar, frequency):
-		raise NotImplementedError()
+    def addBarsFromFeed(self, feed):
+        for dateTime, bars in feed:
+            if bars:
+                self.addBars(bars, feed.getFrequency())
 
-	def getBars(self, instrument, frequency, timezone = None, fromDateTime = None, toDateTime = None):
-		raise NotImplementedError()
+    def addBar(self, instrument, bar, frequency):
+        raise NotImplementedError()
 
+    def getBars(self, instrument, frequency, timezone=None, fromDateTime=None, toDateTime=None):
+        raise NotImplementedError()
