@@ -1,13 +1,13 @@
 # PyAlgoTrade
-# 
-# Copyright 2012 Gabriel Martin Becedillas Ruiz
-# 
+#
+# Copyright 2011-2014 Gabriel Martin Becedillas Ruiz
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #   http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -18,20 +18,20 @@
 .. moduleauthor:: Gabriel Martin Becedillas Ruiz <gabriel.becedillas@gmail.com>
 """
 
-class StrategyAnalyzer:
-	"""Base class for strategy analyzers.
 
-	.. note::
+class StrategyAnalyzer(object):
+    """Base class for strategy analyzers.
 
-		This is a base class and should not be used directly.
-	"""
+    .. note::
 
-	def beforeAttach(self, strat):
-		pass
+        This is a base class and should not be used directly.
+    """
 
-	def attached(self, strat):
-		pass
+    def beforeAttach(self, strat):
+        pass
 
-	def beforeOnBars(self, strat, bars):
-		pass
+    def attached(self, strat):
+        pass
 
+    def beforeOnBars(self, strat, bars):
+        pass
