@@ -1,13 +1,13 @@
 # PyAlgoTrade
-# 
-# Copyright 2012 Gabriel Martin Becedillas Ruiz
-# 
+#
+# Copyright 2011-2014 Gabriel Martin Becedillas Ruiz
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #   http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -18,11 +18,20 @@
 .. moduleauthor:: Gabriel Martin Becedillas Ruiz <gabriel.becedillas@gmail.com>
 """
 
+
 def get_change_percentage(actual, prev):
-	if actual is None or prev is None or prev == 0:
-		raise Exception("Invalid values")
+    if actual is None or prev is None or prev == 0:
+        raise Exception("Invalid values")
 
-	diff = actual-prev
-	ret = diff/float(abs(prev))
-	return ret
+    diff = actual-prev
+    ret = diff / float(abs(prev))
+    return ret
 
+
+def safe_min(left, right):
+    if left is None:
+        return right
+    elif right is None:
+        return left
+    else:
+        return min(left, right)
